<?php
/**
 * @author Acacia Dynamic
 * @copyright 2024 Acacia Dynamic
 * @license private
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

class Shortcode
{
    private static $shortcodeVideo = 'digitalsignage4';

    private static $shortcodePlaylist = 'digitalsignage4_playlist';

    public static function replaceShortcodes($html)
    {
        $htmlBeforeHeaderWithShortcodes = explode('</head>', $html, 2)[0] . '</head>';
        $htmlBeforeHeaderWithoutShortcode = self::eraseShortcodeFromHeader($htmlBeforeHeaderWithShortcodes);

        $htmlAfterHeaderWithShortcodes = explode('</head>', $html, 2)[1];
        $htmlAfterHeaderWithRemplacedShortcodes = self::replaceShortcodeFromContent($htmlAfterHeaderWithShortcodes);

        return $htmlBeforeHeaderWithoutShortcode . $htmlAfterHeaderWithRemplacedShortcodes;
    }

    public static function replaceShortcodeFromContent($html)
    {
        // SHORTCODE VIDEO
        $shortcodesVideo = self::arrayUniqueShortcodeFound($html, self::$shortcodeVideo);
        $shortcodesHtmlVideo = self::generateHtmlForShortcodeVideo($shortcodesVideo);
        foreach ($shortcodesHtmlVideo as $shortcodeString => $shortcodeHtml) {
            $html = str_replace($shortcodeString, $shortcodeHtml, $html);
        }

        // SHORTCODE PLAYLIST
        $shortcodesPlaylist = self::playlistShortcodeFound($html, self::$shortcodePlaylist);

        foreach ($shortcodesPlaylist as $shortcode) {
            $shortcodeHtml = self::generateHtmlForShortcodePlaylistId(self::getShortcodeId($shortcode));
            $html = self::replace_first_str($shortcode, $shortcodeHtml, $html);
        }

        return $html;
    }

    public static function replace_first_str($search_str, $replacement_str, $src_str)
    {
        return (false !== ($pos = strpos($src_str, $search_str))) ? substr_replace($src_str, $replacement_str, $pos, strlen($search_str)) : $src_str;
    }

    public static function generateHtmlForShortcodeVideo($shortcodes)
    {
        $result = [];

        foreach ($shortcodes as $shortcode) {
            $result[$shortcode] = self::generateHtmlForShortcodeVideoId(self::getShortcodeId($shortcode));
        }

        return $result;
    }

    public static function generateHtmlForShortcodePlaylist($shortcodes)
    {
        $result = [];

        foreach ($shortcodes as $shortcode) {
            $result[$shortcode] = self::generateHtmlForShortcodePlaylistId(self::getShortcodeId($shortcode));
        }

        return $result;
    }

    public static function generateHtmlForShortcodePlaylistId($id)
    {
        if (!$id) {
            return '';
        }

        if ($playlist = PlaylistManager::set(new Wp_caller())->get_playlist($id)) {
            $random = rand(0, 10000000);
            $videos = $playlist->get_videos();

            $videos = array_map(
                function ($id) {
                    $video = self::getDemandeFromId($id);

                    return [
                        'urlMp4' => $video->getVideoUrl(),
                        'urlOgv' => $video->getVideoUrlOgv(),
                        'url' => self::urlFromProductId($video->getProductId()),
                    ];
                },
                $videos
            );

            return "
                    <div style='position: relative; width: 100%'>
                    
                         <video id='video_$random' style='width: 100%;' muted='muted' autoplay='autoplay' preload='auto'>
                            <source id='mp4_$random' src='' type='video/mp4'/>
                            <source id='ogv_$random' src='' type='video/ogg'/>
                        </video>
                        
                        <a  target='_blank' id='url_$random' style='position: absolute; width: 100%; height: 100%; top: 0; left: 0' href=''>
                        
                        </a>
                        
                    </div>
                    
                    <script>

                        let videos_playlist_" . $random . ' = ' . json_encode($videos) . ';
                        let video_c_' . $random . " = document.getElementById('video_$random');
                        let cpt_" . $random . ' = 0;

                        lunchVideo_' . $random . '(video_c_' . $random . ', videos_playlist_' . $random . '[cpt_' . $random . ']);

                        video_c_' . $random . ".addEventListener('ended', () => {
                            cpt_" . $random . '++;
                            if (cpt_' . $random . ' >= videos_playlist_' . $random . '.length) 
                                cpt_' . $random . ' = 0;
                            lunchVideo_' . $random . '(video_c_' . $random . ', videos_playlist_' . $random . '[cpt_' . $random . ']);
                        });

                        
                        function lunchVideo_' . $random . "(video_c, video) {

                            video_c.currentTime = 0;

                            let video_mp4 = document.getElementById('mp4_$random');
                            let video_ogv = document.getElementById('ogv_$random');
                            let url = document.getElementById('url_$random');

                            video_mp4.src = video.urlMp4;
                            video_ogv.src = video.urlOgv;
                            url.href = video.url;
                      
                            video_c.load();
                            video_c.play();

                        }

                    </script>
                ";
        }

        return '';
    }

    public static function urlFromProductId($id)
    {
        $id_lang = (int) Configuration::get('PS_LANG_DEFAULT');
        $product = new Product($id, false, $id_lang);
        if (Validate::isLoadedObject($product)) {
            $link = new Link();

            return $link->getProductLink($product);
        }

        return '';
    }

    public static function generateHtmlForShortcodeVideoId($id)
    {
        if (!$id) {
            return '';
        }

        try {
            $demande = self::getDemandeFromId($id);

            return $demande->getVideoPlayer('max-width: 600px;width: 600px', 'max-height:500px;height: 500px', '0', '1');

            /*return "
            <video style='max-width: 100%;' muted='muted' loop autoplay='autoplay' preload='auto'>
                <source src='" . $demande->getVideoUrl() . "' type='video/mp4'>
                <source src='" . $demande->getVideoUrlOgv() . "' type='video/ogg'>
            </video>
            ";*/
        } catch (Exception $e) {
            return '';
        }
    }

    public static function getDemandeFromId($id)
    {
        $demandeManager = DemandeManager::set(new Wp_caller());
        $videosData = $demandeManager->getLocalDemandes('SELECT * FROM %s WHERE `id_demande` = ' . $id . ' LIMIT 1');

        if (!empty($videosData)) {
            return $videosData[0];
        }

        throw new Exception('No video found for id ' . $id);
    }

    public static function getShortcodeId($shorcode)
    {
        if ($shorcode && strpos($shorcode, 'id=') !== false) {
            $datas = explode('id=', $shorcode);

            return str_replace(']', '', $datas[1]);
        }

        return false;
    }

    public static function playlistShortcodeFound($html, $shortcode)
    {
        if (preg_match_all(self::shortcodeRegexGenerator($shortcode), $html, $founds, PREG_PATTERN_ORDER) && $founds) {
            return $founds[0];
        }

        return [];
    }

    public static function arrayUniqueShortcodeFound($html, $shortcode)
    {
        if (preg_match_all(self::shortcodeRegexGenerator($shortcode), $html, $founds, PREG_PATTERN_ORDER) && $founds) {
            return array_unique($founds[0]);
        }

        return [];
    }

    public static function eraseShortcodeFromHeader($html)
    {
        $html = preg_replace(self::shortcodeRegexGenerator(self::$shortcodeVideo), '', $html);
        $html = preg_replace(self::shortcodeRegexGenerator(self::$shortcodePlaylist), '', $html);

        return str_replace(["\r", "\n"], '', $html);
    }

    public static function shortcodeRegexGenerator($shortcodeName)
    {
        return '/\[' . $shortcodeName . '[a-zA-Z0-9 =-]*]/';
    }
}
