<?php
/**
 * @author Acacia Dynamic
 * @copyright 2024 Acacia Dynamic
 * @license private
 */
require_once __DIR__ . '/../../../Kernel/API/Entity/AutomatisationEntity.php';
require_once __DIR__ . '/../../../Kernel/API/Linker/CMS_Linker.php';
require_once __DIR__ . '/../../../Kernel/Translations/DigitalSignageTranslate.php';
require_once 'Manager.php';

if (!defined('_PS_VERSION_')) {
    exit;
}

class AutomatisationManager extends Manager
{
    /**
     * @var CMS_Linker|null
     */
    private $cms;

    private $entity_name = 'DigitalSignage_automatisation';

    /**
     * @param CMS_Linker $cms_linker
     *
     * @throws DigitalSignageException
     */
    public function __construct($cms_linker)
    {
        if (!$cms_linker instanceof CMS_Linker) {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_cms_linker'));
        } else {
            $this->cms = $cms_linker;
        }
    }

    /**
     * @throws DigitalSignageException
     */
    public static function set($cms_linker)
    {
        if (!$cms_linker instanceof CMS_Linker) {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_cms_linker'));
        } else {
            return new AutomatisationManager($cms_linker);
        }
    }

    /**
     * @param AutomatisationEntity $automatisation
     *
     * @throws DigitalSignageException
     */
    public function add_automatisation($automatisation)
    {
        if ($automatisation instanceof AutomatisationEntity) {
            $automatisations_existantes = $this->cms->get_data($this->entity_name);

            if (!$automatisations_existantes) {
                $automatisations_existantes = [];
            }

            $automatisations_existantes[] = $automatisation;
            if ($this->cms->save_data($this->entity_name, $automatisations_existantes)) {
                return true;
            }
        } else {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_parametre_type', 'add_automatisation', 'AutomatisationEntity'));
        }

        return false;
    }

    /**
     * @param AutomatisationEntity $automatisation
     *
     * @throws DigitalSignageException
     */
    public function remove_automatisation($automatisation)
    {
        if ($automatisation instanceof AutomatisationEntity) {
            $automatisations_existantes = $this->cms->get_data($this->entity_name);

            foreach ($automatisations_existantes as $key => $automatisations_existante) {
                if ($automatisations_existante->getId() == $automatisation->getId()) {
                    unset($automatisations_existantes[$key]);
                }
            }

            if ($this->cms->save_data($this->entity_name, $automatisations_existantes)) {
                return true;
            }
        } else {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_parametre_type', 'remove_automatisation', 'AutomatisationEntity'));
        }

        return false;
    }

    /**
     * @return AutomatisationEntity[]
     */
    public function get_automatisations()
    {
        $automatisations_existantes = $this->cms->get_data($this->entity_name);

        if (!$automatisations_existantes) {
            $automatisations_existantes = [];
        }

        return $automatisations_existantes;
    }

    /**
     * @param $id
     *
     * @return array|mixed
     */
    public function get_automatisation($id)
    {
        /**
         * @var AutomatisationEntity[] $automatisations_existantes
         */
        $automatisations_existantes = $this->cms->get_data($this->entity_name);

        if (!$automatisations_existantes) {
            $automatisations_existantes = [];
        }

        foreach ($automatisations_existantes as $automatisation_existante) {
            if ($automatisation_existante->getId() == $id) {
                return $automatisation_existante;
            }
        }

        return false;
    }

    public function get_last_id()
    {
        $automatisations_existantes = $this->cms->get_data($this->entity_name);
        $last_id = 0;
        foreach ($automatisations_existantes as $automatisation_existante) {
            if ($automatisation_existante->getId() > $last_id) {
                $last_id = $automatisation_existante->getId();
            }
        }

        return $last_id;
    }

    public function update_automatisation($automatisation)
    {
        $automatisations_existantes = $this->cms->get_data($this->entity_name);

        foreach ($automatisations_existantes as $key => $automatisation_existante) {
            if ($automatisation->getId() == $automatisation_existante->getId()) {
                $automatisations_existantes[$key] = $automatisation;
            }
        }

        return $this->cms->save_data($this->entity_name, $automatisations_existantes);
    }
}
