<?php
/**
 * @author Acacia Dynamic
 * @copyright 2024 Acacia Dynamic
 * @license private
 */
require_once __DIR__ . '/../../../Kernel/API/Entity/LotEntity.php';
require_once __DIR__ . '/../../../Kernel/API/Linker/CMS_Linker.php';
require_once __DIR__ . '/../../../Kernel/Translations/DigitalSignageTranslate.php';
require_once 'Manager.php';

if (!defined('_PS_VERSION_')) {
    exit;
}

class LotManager extends Manager
{
    /**
     * @var CMS_Linker|null
     */
    private $cms;

    private $entity_name = 'DigitalSignage_lot';

    /**
     * @param CMS_Linker $cms_linker
     *
     * @throws DigitalSignageException
     */
    public function __construct($cms_linker)
    {
        if (!$cms_linker instanceof CMS_Linker) {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_cms_linker'));
        } else {
            $this->cms = $cms_linker;
        }
    }

    /**
     * @throws DigitalSignageException
     */
    public static function set($cms_linker)
    {
        if (!$cms_linker instanceof CMS_Linker) {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_cms_linker'));
        } else {
            return new LotManager($cms_linker);
        }
    }

    /**
     * @param AutomatisationEntity $lot
     *
     * @throws DigitalSignageException
     */
    public function add_lot($lot)
    {
        if ($lot instanceof LotEntity) {
            $lot_existants = $this->cms->get_data($this->entity_name);

            if (!$lot_existants) {
                $lot_existants = [];
            }

            $lot_existants[] = $lot;
            if ($this->cms->save_data($this->entity_name, $lot_existants)) {
                return true;
            }
        } else {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_parametre_type', 'add_lot', 'LotEntity'));
        }

        return false;
    }

    /**
     * @param AutomatisationEntity $lot
     *
     * @throws DigitalSignageException
     */
    public function remove_lot($lot)
    {
        if ($lot instanceof LotEntity) {
            $lot_existants = $this->cms->get_data($this->entity_name);

            foreach ($lot_existants as $key => $lot_existant) {
                if ($lot_existant->getId() == $lot->getId()) {
                    unset($lot_existants[$key]);
                }
            }

            if ($this->cms->save_data($this->entity_name, $lot_existants)) {
                return true;
            }
        } else {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_parametre_type', 'remove_lot', 'LotEntity'));
        }

        return false;
    }

    public function get_products($liste_categories, $prix_mini, $prix_max)
    {
        $liste_products = [];
        $args = [
            'limit' => -1,
            'status' => 'publish',
        ];

        // 'return' => 'ids',
        if (isset($liste_categories) && ($liste_categories != '')) {
            $args['product_category_id'] = explode(',', $liste_categories);
        }

        $products = [];
        foreach ($args['product_category_id'] as $it_categorie) {
            $tmpCategorie = new Category($it_categorie);
            // echo '<hr/>TmpCategorie';
            // var_dump($tmpCategorie);
            // echo '<hr/>Products';
            $productsGets = $tmpCategorie->getProducts($this->context->language->id, 1, 999999999);
            // var_dump($productsGets);
            foreach ($productsGets as $itProduct) {
                $products[$itProduct['id_product']] = $itProduct;
                // var_dump($itProduct->get_id());
            }
        }

        // $products = wc_get_products( $args );

        foreach ($products as $product) {
            $idProduct = $product['id_product'];
            $priceProduct = $product['price'];
            $autoPriceMin = (int) $prix_mini;
            $autoPirceMax = (int) $prix_max;

            if ($autoPriceMin == -1 && $autoPirceMax == -1) {
                $liste_products[] = $idProduct;
            } elseif ($autoPriceMin >= 0 && $autoPirceMax == -1) {
                if ($priceProduct >= $autoPriceMin) {
                    $liste_products[] = $idProduct;
                }
            } elseif ($autoPriceMin >= 0 && $autoPirceMax >= 0) {
                if (($priceProduct >= $autoPriceMin) && ($priceProduct <= $autoPirceMax)) {
                    $liste_products[] = $idProduct;
                }
            }
        }

        return $liste_products;
    }

    /**
     * @return LotEntity[]
     */
    public function get_lots()
    {
        $lot_existants = $this->cms->get_data($this->entity_name);

        if (!$lot_existants) {
            $lot_existants = [];
        }

        // determiner si video en cours de traitement si oui retourner "etat" en cours sinon terminé
        // determnier le nombre de video a generer et généré
        foreach ($lot_existants as $lot_existant) {
            $nb_videos = 0;
            $nb_videos_cree = 0;
            // rechercher les id_lot correspondants dans la liste des videos a créer
            $videos = DemandeManager::set(Wp_caller::getInstance())->getLocalDemandes('SELECT * FROM %s WHERE `automatique` = ' . ($lot_existant->getId() + 1));
            if ($videos) {
                foreach ($videos as $video) {
                    ++$nb_videos;
                }
            }
            $videos = DemandeManager::set(Wp_caller::getInstance())->getLocalDemandes("SELECT * FROM %s WHERE flag='completed' AND `automatique` = " . ($lot_existant->getId() + 1));
            if ($videos) {
                foreach ($videos as $video) {
                    ++$nb_videos_cree;
                }
            }
            if ($nb_videos_cree == $nb_videos) {
                $lot_existant->setEtat('Terminé');
            } else {
                $lot_existant->setEtat('En cours');
            }

            $lot_existant->setCreated($nb_videos_cree . '/' . $nb_videos);
        }

        return $lot_existants;
    }

    /**
     * @param $id
     *
     * @return array|mixed
     */
    public function get_lot($id)
    {
        /**
         * @var AutomatisationEntity[] $lot_existants
         */
        $lot_existants = $this->cms->get_data($this->entity_name);

        if (!$lot_existants) {
            $lot_existants = [];
        }

        foreach ($lot_existants as $lot_existant) {
            if ($lot_existant->getId() == $id) {
                return $lot_existant;
            }
        }

        return false;
    }

    public function get_last_id()
    {
        $lot_existants = $this->cms->get_data($this->entity_name);
        $last_id = 0;
        foreach ($lot_existants as $lot_existant) {
            if ($lot_existant->getId() > $last_id) {
                $last_id = $lot_existant->getId();
            }
        }

        return $last_id;
    }

    public function update_lot($lot)
    {
        $lot_existants = $this->cms->get_data($this->entity_name);

        foreach ($lot_existants as $key => $lot_existant) {
            if ($lot->getId() == $lot_existant->getId()) {
                $lot_existants[$key] = $lot;
            }
        }

        return $this->cms->save_data($this->entity_name, $lot_existants);
    }
}
