<?php
/**
 * @author Acacia Dynamic
 * @copyright 2024 Acacia Dynamic
 * @license private
 */
require_once __DIR__ . '/../../../Kernel/API/Entity/PlaylistEntity.php';
require_once __DIR__ . '/../../../Kernel/API/Linker/CMS_Linker.php';
require_once __DIR__ . '/../../../Kernel/Translations/DigitalSignageTranslate.php';
require_once 'Manager.php';

if (!defined('_PS_VERSION_')) {
    exit;
}

class PlaylistManager extends Manager
{
    /**
     * @var CMS_Linker|null
     */
    private $cms;

    private $entity_name = 'DigitalSignage_playlist';

    /**
     * @param CMS_Linker $cms_linker
     *
     * @throws DigitalSignageException
     */
    public function __construct($cms_linker)
    {
        if (!$cms_linker instanceof CMS_Linker) {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_cms_linker'));
        } else {
            $this->cms = $cms_linker;
        }
    }

    /**
     * @throws DigitalSignageException
     */
    public static function set($cms_linker)
    {
        if (!$cms_linker instanceof CMS_Linker) {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_cms_linker'));
        } else {
            return new PlaylistManager($cms_linker);
        }
    }

    /**
     * @param PlaylistEntity $playlist
     *
     * @throws DigitalSignageException
     */
    public function add_playlist($playlist)
    {
        if ($playlist instanceof PlaylistEntity) {
            $playlists_existantes = $this->cms->get_data($this->entity_name);

            if (!$playlists_existantes) {
                $playlists_existantes = [];
            }

            $playlists_existantes[] = $playlist;

            return $this->cms->save_data($this->entity_name, $playlists_existantes);
        } else {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_parametre_type', 'add_playlist', 'PlaylistEntity'));
        }
    }

    /**
     * @param PlaylistEntity $playlist
     *
     * @throws DigitalSignageException
     */
    public function remove_playlist($playlist)
    {
        if ($playlist instanceof PlaylistEntity) {
            $playlists_existantes = $this->cms->get_data($this->entity_name);

            if (($key = array_search($playlist, $playlists_existantes)) !== false) {
                unset($playlists_existantes[$key]);
            }

            if ($this->cms->save_data($this->entity_name, $playlists_existantes)) {
                return true;
            }

            return false;
        } else {
            throw new DigitalSignageException(DigitalSignageTranslate::getTraduction('mauvais_parametre_type', 'remove_playlist', 'PlaylistEntity'));
        }
    }

    /**
     * @return mixed|PlaylistEntity[]
     */
    public function get_playlists()
    {
        $playlists_existantes = $this->cms->get_data($this->entity_name);

        if (!$playlists_existantes) {
            $playlists_existantes = [];
        }

        return $playlists_existantes;
    }

    /**
     * @param $id
     *
     * @return array|mixed
     */
    public function get_playlist($id)
    {
        /**
         * @var PlaylistEntity[] $playlists_existantes
         */
        $playlists_existantes = $this->cms->get_data($this->entity_name);

        if (!$playlists_existantes) {
            $playlists_existantes = [];
        }

        foreach ($playlists_existantes as $playlist_existante) {
            if ($playlist_existante->get_id() == $id) {
                return $playlist_existante;
            }
        }

        return false;
    }

    public function get_last_id()
    {
        $playlists_existantes = $this->cms->get_data($this->entity_name);
        $last_id = 0;

        if ($playlists_existantes) {
            foreach ($playlists_existantes as $playlist_existante) {
                if ($playlist_existante->get_id() > $last_id) {
                    $last_id = $playlist_existante->get_id();
                }
            }
        }

        return $last_id;
    }

    /**
     * @param PlaylistEntity $playlist
     */
    public function update_playlist($playlist)
    {
        $playlists_existantes = $this->cms->get_data($this->entity_name);
        foreach ($playlists_existantes as $key => $playlist_existante) {
            if ((int) $playlist->get_id() == (int) $playlist_existante->get_id()) {
                $playlists_existantes[$key] = $playlist;

                return $this->cms->save_data($this->entity_name, $playlists_existantes);
            }
        }

        return false;
    }
}
