<?php
/**
 * @author Acacia Dynamic
 * @copyright 2024 Acacia Dynamic
 * @license private
 */
require_once __DIR__ . '/../Kernel/Translations/DigitalSignageTranslate.php';
require_once __DIR__ . '/../Kernel/API/Manager/ForfaitManager.php';
require_once __DIR__ . '/../Kernel/API/Manager/ForfaitManager.php';
require_once 'Controller_i.php';

if (!class_exists('Smarty')) {
    require_once __DIR__ . '/../vendor/smarty/smarty/libs/Smarty.class.php';
}

if (!defined('_PS_VERSION_')) {
    exit;
}

abstract class DigitalSignageController extends Smarty implements Controller_i
{
    protected function setWPTemplate($link)
    {
        $this->setGlonals();
        $this->checkUpdate();
        $this->checkWooCommerceInstance();
        $this->trialMessage();
        $this->my_admin_notices();

        try {
            $this->assign('t', get_class(new DigitalSignageTranslate()));
            $this->display(plugin_dir_path(__FILE__) . '../../views/templates/admin/' . $link . '.tpl');
        } catch (SmartyException  $e) {
            echo $e->getMessage();
        } catch (Exception  $e) {
            echo $e->getMessage();
        }
    }

    public function my_admin_notices()
    {
        // array_unique supprime les doublons pouvant être generés dans le main du module (digitalsignage.php) car il est executé plusieurs fois avant l'ouverture d'une page.
        $errors = Context::getContext()->cookie->errors;
        if ($errors != '') {
            echo '<div style="font-size: 1.2em" class="error notice is-dismissible auto-dismiss"><p>' . $errors . '</p></div>';
        }

        // array_unique supprimes les doublons pouvans etre generés dans le main du module (digitalsignage.php) car il est executé plusieurs fois avant l'ouverture d'une page.
        $success = Context::getContext()->cookie->success;
        if ($success != '') {
            echo '<div style="font-size: 1.2em" class="updated notice is-dismissible auto-dismiss"><p>' . $success . '</p></div>';
        }

        Context::getContext()->cookie->errors = '';
        Context::getContext()->cookie->success = '';
    }

    private function checkWooCommerceInstance()
    {
        if (!Tools_DS4::isPrestashop()) {
            if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))) || !class_exists('WooCommerce')) {
                Context::getContext()->cookie->errors = DigitalSignageTranslate::getTraduction('Extension_wooCommerce_pas_installe', DigitalSignageTranslate::getTraduction('Digital_Signage_4'));
            }
        }
    }

    private function setGlonals()
    {
        if (!isset(Context::getContext()->cookie->errors)) {
            Context::getContext()->cookie->errors = '';
        }
        if (!isset(Context::getContext()->cookie->success)) {
            Context::getContext()->cookie->success = '';
        }
    }

    private function trialMessage()
    {
        $forfait = ForfaitManager::instance()->getForfait(ForfaitManager::instance()->getToken(), true);
        if ($forfait && $forfait->getTrial() == true) {
            echo '<div style="font-size: 1.2em; border-left: 4px solid #25b9d7;" class="info notice is-dismissible auto-dismiss"><p>';
            echo DigitalSignageTranslate::getTraduction('Message_compte_essai', DigitalSignageTranslate::getTraduction('Digital_Signage_4'));
            echo '<br>' . DigitalSignageTranslate::getTraduction('Message_upgrade_compte', Tools_DS4::getAcaciaRedirectionPageUrl('account')) . '</p></div>';
        }
    }

    private function checkUpdate()
    {
    }
}
