<?php
/**
 * @author Acacia Dynamic
 * @copyright 2024 Acacia Dynamic
 * @license private
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

// require_once(dirname(__FILE__).'/../../../config/config.inc.php');
// require_once(dirname(__FILE__).'/../../../init.php');

// Initialiser le contexte PrestaShop
$context = Context::getContext();

class WpDbClassInterface
{
    private $register_error = true;

    public $prefix;

    public $last_error = '';

    public $insert_id;

    private static $_instance;

    public static function getInstance()
    {
        if (WpDbClassInterface::$_instance == null) {
            WpDbClassInterface::$_instance = new WpDbClassInterface();
        }

        return WpDbClassInterface::$_instance;
    }

    private function __construct()
    {
        $this->prefix = Db::getInstance()->getPrefix();
    }

    public function hide_errors()
    {
        $this->register_error = false;
    }

    public function _real_escape($datas)
    {
        return pSQL(mb_convert_encoding($datas, 'ISO-8859-1', 'UTF-8'));
    }

    public function get_var($query = null, $x = 0, $y = 0)
    {
        $datas = null;
        if ($query) {
            try {
                $datas = Db::getInstance()->ExecuteS($query);

                if ($datas == false) {
                    throw new Exception(Db::getInstance()->getMsgError());
                }
            } catch (Exception $e) {
                $this->last_error = $e->getMessage();
                if ($this->register_error) {
                    throw new Exception($e->getMessage());
                }
            }
        }

        return $datas;
    }

    public function show_errors()
    {
        $this->register_error = true;
    }

    public function query($sql)
    {
        $result = Db::getInstance()->Execute($sql);
        if ($result) {
            $this->insert_id = Db::getInstance()->Insert_ID();
        }

        return $result;
    }

    public function get_results($sql, $ARRAY_A)
    {
        try {
            return Db::getInstance()->executeS($sql);
        } catch (PrestaShopDatabaseException $e) {
            return Db::getInstance()->execute($sql);
        }
    }
}

function site_url()
{
    return get_site_url();
}

function get_site_icon_url()
{
    return get_site_url() . 'img/' . Configuration::get('PS_LOGO');
}

function get_site_url()
{
    return Context::getContext()->shop->getBaseURL(true);
}

function get_bloginfo($param)
{
    switch ($param) {
        case 'name' :
            return get_option('PS_SHOP_NAME', '');

        case 'language' :
            return Language::getLanguages(true)[0]['iso_code'];

        default:
            break;
    }
}

function apply_filters($hook, $value)
{
    return $value;
}

function get_option($option, $default = false)
{
    if ($option == 'active_plugins') {
        return ['woocommerce/woocommerce.php'];
    }

    $data = Configuration::get($option);

    if ($data) {
        return $data;
    }

    return $default;
}

function update_option($option, $datas)
{
    return Configuration::updateValue($option, $datas);
}

function delete_option($option)
{
    return Configuration::deleteByName($option);
}

function plugin_dir_path($file)
{
    return trailingslashit(dirname($file));
}

function plugin_dir_url($source = '')
{
    $baseUri = Context::getContext()->shop->getBaseURL(true);

    // Construire l'URL complète vers le dossier du module
    $moduleUrl = $baseUri . 'modules/';

    return $moduleUrl;
}

function get_admin_url()
{
    return get_site_url() . basename(_PS_ADMIN_DIR_) . '/';
}

function trailingslashit($string)
{
    return untrailingslashit($string) . '/';
}

function untrailingslashit($string)
{
    return rtrim($string, '/\\');
}

function getModuleDirName()
{
    return 'digitalsignage';
}

function get_plugin_data($a = '', $b = '', $c = '')
{
    $module = Module::getInstanceByName('digitalsignage');

    return [
        'Name' => DigitalSignageTranslate::getTraduction('Digital_Signage_4'),
        'PluginURI' => plugin_dir_url(),
        'PluginDirName' => getModuleDirName(),
        'Version' => $module->version,
        'AuthorName' => 'Acacia dynamic',
        'AuthorURI' => 'https://acacia-dynamic.com/',
    ];
}

function refresh_local_token()
{
    if (!ForfaitManager::instance()->getToken()) {
        $forfait = new ForfaitEntity();
        $success = $forfait->fromArray(Wp_caller::getInstance()->get_data(Wp_caller::FORFAIT));

        if ($success) {
            ForfaitManager::instance()->setForfait($forfait);
        }
    }
}

function get_categories()
{
    $cats = Category::getCategories(false, true, false);
    $categories = [];

    foreach ($cats as $cat) {
        if ($cat['id_parent'] !== '0') {
            if ($cat['id_parent'] == '1') {
                $cat['id_parent'] = '0';
            }
            $categories[] = new CategorieInterface(
                $cat['id_parent'],
                $cat['id_category'],
                ' ' . $cat['name']
            );
        }
    }

    return $categories;
}

function wc_get_product($id = false)
{
    if ($id) {
        return new PS_Product($id);
    }

    return false;
}

class PS_Product extends Product
{
    public function __construct($id)
    {
        parent::__construct($id);
    }

    public function get_permalink()
    {
        return Context::getContext()->link->getAdminLink('AdminProducts', true, ['id_product' => $this->id]);
    }

    public function get_name()
    {
        $names = $this->name;

        if (is_array($names)) {
            $names = array_values($names);

            return $names[0];
        }

        return $this->name;
    }
}

class CategorieInterface
{
    public $parent;

    public $term_id;

    public $name;

    public function __construct($parent, $term_id, $name)
    {
        $this->parent = $parent;
        $this->term_id = $term_id;
        $this->name = $name;
    }
}
